/**
 * NetXMS - open source network management system
 * Copyright (C) 2003-2011 Victor Kirhenshtein
 * <p>
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * <p>
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * <p>
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package org.netxms.ui.android.main.dashboards.configs;

import org.simpleframework.xml.Root;
import org.simpleframework.xml.Serializer;
import org.simpleframework.xml.core.Persister;

import java.io.StringWriter;
import java.io.Writer;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

/**
 * Abstract base class for all dashboard element configs
 */
@Root(name = "element", strict = false)
public abstract class DashboardElementConfig {
    private DashboardElementLayout layout;

    /**
     * Create XML from configuration.
     *
     * @return XML document
     * @throws Exception if the schema for the object is not valid
     */
    public String createXml() throws Exception {
        Serializer serializer = new Persister();
        Writer writer = new StringWriter();
        serializer.write(this, writer);
        return writer.toString();
    }

    /**
     * @return the layout
     */
    public DashboardElementLayout getLayout() {
        return layout;
    }

    /**
     * @param layout the layout to set
     */
    public void setLayout(DashboardElementLayout layout) {
        this.layout = layout;
    }

    /**
     * Get list of referenced object IDs
     *
     * @return
     */
    public Set<Long> getObjects() {
        return new HashSet<Long>(0);
    }

    /**
     * Get list of referenced DCI IDs. Key is DCI iD and value is node ID.
     *
     * @return
     */
    public Map<Long, Long> getDataCollectionItems() {
        return new HashMap<Long, Long>(0);
    }
}
