/**
 * NetXMS - open source network management system
 * Copyright (C) 2003-2023 Victor Kirhenshtein
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package org.netxms.ui.eclipse.widgets.internal;

import org.eclipse.jface.text.rules.ICharacterScanner;
import org.eclipse.jface.text.rules.IPredicateRule;
import org.eclipse.jface.text.rules.IToken;
import org.eclipse.jface.text.rules.Token;

/**
 * Detects code part of the config
 */
public class CodePatternRule implements IPredicateRule
{
	private IToken successToken;
	
	/**
	 * @param successToken
	 */
	public CodePatternRule(IToken successToken)
	{
		this.successToken = successToken;
	}

   /**
    * @see org.eclipse.jface.text.rules.IRule#evaluate(org.eclipse.jface.text.rules.ICharacterScanner)
    */
	@Override
	public IToken evaluate(ICharacterScanner scanner)
	{
		int chars = 0;
		while(true)
		{
			int ch = scanner.read();
			if (ch == ICharacterScanner.EOF)
				break;
         if ((ch == '#') || (ch == '"') || (ch == '*') || (ch == '[') || (ch == '$'))
			{
				scanner.unread();
				break;
			}
			chars++;
		}
		return (chars == 0) ? Token.UNDEFINED : successToken;
	}

   /**
    * @see org.eclipse.jface.text.rules.IPredicateRule#evaluate(org.eclipse.jface.text.rules.ICharacterScanner, boolean)
    */
	@Override
	public IToken evaluate(ICharacterScanner scanner, boolean resume)
	{
		return evaluate(scanner);
	}

   /**
    * @see org.eclipse.jface.text.rules.IPredicateRule#getSuccessToken()
    */
	@Override
	public IToken getSuccessToken()
	{
		return successToken;
	}
}
