/**
 * NetXMS - open source network management system
 * Copyright (C) 2003-2011 Victor Kirhenshtein
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package org.netxms.ui.eclipse.filemanager.dialogs.helpers;

import org.eclipse.jface.viewers.ITableLabelProvider;
import org.eclipse.jface.viewers.LabelProvider;
import org.eclipse.swt.graphics.Image;
import org.eclipse.ui.model.WorkbenchLabelProvider;
import org.netxms.client.server.ServerFile;
import org.netxms.ui.eclipse.console.resources.RegionalSettings;
import org.netxms.ui.eclipse.filemanager.dialogs.SelectServerFileDialog;

/**
 * Label provider for ServerFile objects
 *
 */
public class ServerFileLabelProvider extends LabelProvider implements ITableLabelProvider
{
	private WorkbenchLabelProvider wbLabelProvider;
	
	public ServerFileLabelProvider()
	{
		wbLabelProvider = new WorkbenchLabelProvider();
	}
	
   /**
    * @see org.eclipse.jface.viewers.ITableLabelProvider#getColumnImage(java.lang.Object, int)
    */
	@Override
	public Image getColumnImage(Object element, int columnIndex)
	{
		if (columnIndex == 0)
			return getImage(element);
		return null;
	}

   /**
    * @see org.eclipse.jface.viewers.ITableLabelProvider#getColumnText(java.lang.Object, int)
    */
	@Override
	public String getColumnText(Object element, int columnIndex)
	{
		switch(columnIndex)
		{
			case SelectServerFileDialog.COLUMN_NAME:
				return getText(element);
			case SelectServerFileDialog.COLUMN_SIZE:
				return Long.toString(((ServerFile)element).getSize());
			case SelectServerFileDialog.COLUMN_MODTIME:
            return RegionalSettings.getDateTimeFormat().format(((ServerFile)element).getModificationTime());
		}
		return null;
	}

   /**
    * @see org.eclipse.jface.viewers.LabelProvider#getImage(java.lang.Object)
    */
	@Override
	public Image getImage(Object element)
	{
		return wbLabelProvider.getImage(element);
	}

   /**
    * @see org.eclipse.jface.viewers.LabelProvider#getText(java.lang.Object)
    */
	@Override
	public String getText(Object element)
	{
		return wbLabelProvider.getText(element);
	}

   /**
    * @see org.eclipse.jface.viewers.BaseLabelProvider#dispose()
    */
	@Override
	public void dispose()
	{
		wbLabelProvider.dispose();
		super.dispose();
	}
}
