/**
 * NetXMS - open source network management system
 * Copyright (C) 2003-2023 Victor Kirhenshtein
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package org.netxms.ui.eclipse.datacollection.objecttabs;

import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Composite;
import org.netxms.client.objects.AbstractObject;
import org.netxms.client.objects.Cluster;
import org.netxms.client.objects.Container;
import org.netxms.client.objects.EntireNetwork;
import org.netxms.client.objects.Rack;
import org.netxms.client.objects.ServiceRoot;
import org.netxms.client.objects.Subnet;
import org.netxms.client.objects.Zone;
import org.netxms.ui.eclipse.datacollection.widgets.ThresholdSummaryWidget;
import org.netxms.ui.eclipse.objectview.objecttabs.ObjectTab;
import org.netxms.ui.eclipse.tools.VisibilityValidator;

/**
 * Threshold violation summary page
 */
public class ThresholdSummary extends ObjectTab
{
	private ThresholdSummaryWidget tsw;
	
   /**
    * @see org.netxms.ui.eclipse.objectview.objecttabs.ObjectTab#createTabContent(org.eclipse.swt.widgets.Composite)
    */
	@Override
	protected void createTabContent(Composite parent)
	{
		tsw = new ThresholdSummaryWidget(parent, SWT.NONE, getViewPart(), new VisibilityValidator() {
         @Override
         public boolean isVisible()
         {
            return isActive();
         }
      });
	}

   /**
    * @see org.netxms.ui.eclipse.objectview.objecttabs.ObjectTab#objectChanged(org.netxms.client.objects.AbstractObject)
    */
	@Override
	public void objectChanged(AbstractObject object)
	{
		tsw.setObject(object);
	}

   /**
    * @see org.netxms.ui.eclipse.objectview.objecttabs.ObjectTab#showForObject(org.netxms.client.objects.AbstractObject)
    */
	@Override
	public boolean showForObject(AbstractObject object)
	{
		return (object instanceof EntireNetwork) || (object instanceof Zone) ||
				(object instanceof Subnet) || (object instanceof ServiceRoot) ||
				(object instanceof Container) || (object instanceof Rack) || 
				(object instanceof Cluster);
	}

   /**
    * @see org.netxms.ui.eclipse.objectview.objecttabs.ObjectTab#refresh()
    */
	@Override
	public void refresh()
	{
		tsw.refresh();
	}
	
   /**
    * @see org.netxms.ui.eclipse.objectview.objecttabs.ObjectTab#selected()
    */
	@Override
	public void selected()
	{
	   super.selected();
	   if (getObject() != null)
	      tsw.refresh();
	}
}
