/**
 * NetXMS - open source network management system
 * Copyright (C) 2003-2020 Victor Kirhenshtein
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package org.netxms.ui.eclipse.objectbrowser;

import org.eclipse.core.runtime.IAdapterFactory;
import org.eclipse.ui.model.IWorkbenchAdapter;
import org.netxms.client.objects.AbstractObject;
import org.netxms.ui.eclipse.objectbrowser.api.ObjectAdapter;

/**
 * Adapter factory for NetXMS objects
 */
public class ObjectAdapterFactory implements IAdapterFactory
{
	@SuppressWarnings("rawtypes")
	private static final Class[] supportedClasses = 
	{
		IWorkbenchAdapter.class
	};

   /**
    * @see org.eclipse.core.runtime.IAdapterFactory#getAdapterList()
    */
	@Override
	public Class<?>[] getAdapterList()
	{
		return supportedClasses;
	}

   /**
    * @see org.eclipse.core.runtime.IAdapterFactory#getAdapter(java.lang.Object, java.lang.Class)
    */
	@SuppressWarnings({ "unchecked", "rawtypes" })
   @Override
	public Object getAdapter(Object adaptableObject, Class adapterType)
	{
		if ((adapterType == IWorkbenchAdapter.class) && 
		    (adaptableObject instanceof AbstractObject) &&
		    (((AbstractObject)adaptableObject).getObjectClass() < AbstractObject.OBJECT_CUSTOM))
		{
			return new ObjectAdapter();
		}
		return null;
	}
}
