/**
 * NetXMS - open source network management system
 * Copyright (C) 2003-2020 Victor Kirhenshtein
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package org.netxms.ui.eclipse.objectbrowser.api;

import java.util.Iterator;
import java.util.UUID;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.swt.graphics.Image;
import org.eclipse.ui.model.IWorkbenchAdapter;
import org.netxms.client.NXCSession;
import org.netxms.client.objects.AbstractObject;
import org.netxms.client.objects.UnknownObject;
import org.netxms.ui.eclipse.console.resources.SharedIcons;
import org.netxms.ui.eclipse.imagelibrary.shared.ImageProvider;
import org.netxms.ui.eclipse.objectbrowser.Activator;
import org.netxms.ui.eclipse.shared.ConsoleSharedData;

/**
 * NetXMS object adapter
 */
public class ObjectAdapter implements IWorkbenchAdapter
{
   /**
    * @see org.eclipse.ui.model.IWorkbenchAdapter#getChildren(java.lang.Object)
    */
	@Override
	public Object[] getChildren(Object o)
	{
		return ((AbstractObject)o).getChildrenAsArray();
	}

   /**
    * @see org.eclipse.ui.model.IWorkbenchAdapter#getImageDescriptor(java.lang.Object)
    */
	@Override
	public ImageDescriptor getImageDescriptor(Object object)
	{
		if (object instanceof UnknownObject)
			return SharedIcons.UNKNOWN_OBJECT;

      UUID iconId = ((AbstractObject)object).getIcon();
      if (iconId != null)
      {
         Image icon = ImageProvider.getInstance().getObjectIcon(iconId);
         if (icon != null)
            return ImageDescriptor.createFromImage(icon);
      }

		switch(((AbstractObject)object).getObjectClass())
		{
         case AbstractObject.OBJECT_ACCESSPOINT:
            return Activator.getImageDescriptor("icons/access_point.png"); //$NON-NLS-1$
         case AbstractObject.OBJECT_ASSET:
            return Activator.getImageDescriptor("icons/asset.png"); //$NON-NLS-1$
         case AbstractObject.OBJECT_ASSETGROUP:
            return Activator.getImageDescriptor("icons/asset-group.png"); //$NON-NLS-1$
         case AbstractObject.OBJECT_ASSETROOT:
            return Activator.getImageDescriptor("icons/asset-root.png"); //$NON-NLS-1$
         case AbstractObject.OBJECT_BUSINESSSERVICE:
         case AbstractObject.OBJECT_BUSINESSSERVICEPROTOTYPE:
         case AbstractObject.OBJECT_BUSINESSSERVICEROOT:
            return Activator.getImageDescriptor("icons/business_service.png"); //$NON-NLS-1$
         case AbstractObject.OBJECT_CHASSIS:
            return Activator.getImageDescriptor("icons/chassis.png"); //$NON-NLS-1$
         case AbstractObject.OBJECT_CLUSTER:
            return Activator.getImageDescriptor("icons/cluster.png"); //$NON-NLS-1$
         case AbstractObject.OBJECT_COLLECTOR:
            return Activator.getImageDescriptor("icons/collector.png"); //$NON-NLS-1$
         case AbstractObject.OBJECT_CONDITION:
            return Activator.getImageDescriptor("icons/condition.gif"); //$NON-NLS-1$
         case AbstractObject.OBJECT_CONTAINER:
            return Activator.getImageDescriptor("icons/container.png"); //$NON-NLS-1$
         case AbstractObject.OBJECT_DASHBOARD:
            return Activator.getImageDescriptor("icons/dashboard.png"); //$NON-NLS-1$
         case AbstractObject.OBJECT_DASHBOARDGROUP:
            return Activator.getImageDescriptor("icons/dashboard_group.png"); //$NON-NLS-1$
         case AbstractObject.OBJECT_DASHBOARDROOT:
            return Activator.getImageDescriptor("icons/dashboard_root.gif"); //$NON-NLS-1$
         case AbstractObject.OBJECT_INTERFACE:
            return Activator.getImageDescriptor("icons/interface.png"); //$NON-NLS-1$
         case AbstractObject.OBJECT_MOBILEDEVICE:
            return Activator.getImageDescriptor("icons/mobile_device.png"); //$NON-NLS-1$
			case AbstractObject.OBJECT_NETWORK:
				return Activator.getImageDescriptor("icons/network.png"); //$NON-NLS-1$
         case AbstractObject.OBJECT_NETWORKMAP:
            return Activator.getImageDescriptor("icons/netmap.png"); //$NON-NLS-1$
         case AbstractObject.OBJECT_NETWORKMAPGROUP:
            return Activator.getImageDescriptor("icons/netmap_group.png"); //$NON-NLS-1$
         case AbstractObject.OBJECT_NETWORKMAPROOT:
            return Activator.getImageDescriptor("icons/netmap_root.gif"); //$NON-NLS-1$
         case AbstractObject.OBJECT_NETWORKSERVICE:
            return Activator.getImageDescriptor("icons/network_service.png"); //$NON-NLS-1$
         case AbstractObject.OBJECT_NODE:
            return Activator.getImageDescriptor("icons/node.png"); //$NON-NLS-1$
         case AbstractObject.OBJECT_RACK:
            return Activator.getImageDescriptor("icons/rack.gif"); //$NON-NLS-1$
         case AbstractObject.OBJECT_SENSOR:
            return Activator.getImageDescriptor("icons/sensor.gif"); //$NON-NLS-1$
			case AbstractObject.OBJECT_SERVICEROOT:
				return Activator.getImageDescriptor("icons/service_root.png"); //$NON-NLS-1$
         case AbstractObject.OBJECT_SUBNET:
            return Activator.getImageDescriptor("icons/subnet.png"); //$NON-NLS-1$
         case AbstractObject.OBJECT_TEMPLATE:
            return Activator.getImageDescriptor("icons/template.png"); //$NON-NLS-1$
         case AbstractObject.OBJECT_TEMPLATEGROUP:
            return Activator.getImageDescriptor("icons/template_group.png"); //$NON-NLS-1$
			case AbstractObject.OBJECT_TEMPLATEROOT:
				return Activator.getImageDescriptor("icons/template_root.png"); //$NON-NLS-1$
         case AbstractObject.OBJECT_VPNCONNECTOR:
            return Activator.getImageDescriptor("icons/vpn.png"); //$NON-NLS-1$
         case AbstractObject.OBJECT_ZONE:
            return Activator.getImageDescriptor("icons/zone.gif"); //$NON-NLS-1$
			default:
				return SharedIcons.UNKNOWN_OBJECT;
		}
	}

   /**
    * @see org.eclipse.ui.model.IWorkbenchAdapter#getLabel(java.lang.Object)
    */
	@Override
	public String getLabel(Object o)
	{
      return ((AbstractObject)o).getNameWithAlias();
	}

   /**
    * @see org.eclipse.ui.model.IWorkbenchAdapter#getParent(java.lang.Object)
    */
	@Override
	public Object getParent(Object o)
	{
      NXCSession session = ConsoleSharedData.getSession();
		if (session != null)
		{
			Iterator<Long> it = ((AbstractObject)o).getParents();
			return it.hasNext() ? session.findObjectById(it.next()) : null;
		}
		return null;
	}
}
