/**
 * NetXMS - open source network management system
 * Copyright (C) 2003-2020 Victor Kirhenshtein
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package org.netxms.ui.eclipse.objectview.objecttabs.helpers;

import org.eclipse.jface.viewers.ITableColorProvider;
import org.eclipse.jface.viewers.ITableLabelProvider;
import org.eclipse.jface.viewers.LabelProvider;
import org.eclipse.swt.graphics.Color;
import org.eclipse.swt.graphics.Image;
import org.netxms.client.NXCSession;
import org.netxms.client.objects.AbstractNode;
import org.netxms.client.objects.Rack;
import org.netxms.ui.eclipse.console.resources.StatusDisplayInfo;
import org.netxms.ui.eclipse.objectview.Messages;
import org.netxms.ui.eclipse.objectview.objecttabs.NodesTab;
import org.netxms.ui.eclipse.shared.ConsoleSharedData;

/**
 * Label provider for node list
 */
public class NodeListLabelProvider extends LabelProvider implements ITableLabelProvider, ITableColorProvider
{
   private NXCSession session = ConsoleSharedData.getSession();
   
   /**
    * @see org.eclipse.jface.viewers.ITableLabelProvider#getColumnImage(java.lang.Object, int)
    */
	@Override
	public Image getColumnImage(Object element, int columnIndex)
	{
		return null;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.viewers.ITableLabelProvider#getColumnText(java.lang.Object, int)
	 */
	@Override
	public String getColumnText(Object element, int columnIndex)
	{
		AbstractNode node = (AbstractNode)element;
		switch(columnIndex)
		{
			case NodesTab.COLUMN_SYS_DESCRIPTION:
				return node.getSystemDescription();
			case NodesTab.COLUMN_ID:
				return Long.toString(node.getObjectId());
			case NodesTab.COLUMN_NAME:
            return node.getNameWithAlias();
			case NodesTab.COLUMN_STATUS:
				return StatusDisplayInfo.getStatusText(node.getStatus());
			case NodesTab.COLUMN_IP_ADDRESS:
				return node.getPrimaryIP().isValidUnicastAddress() ? node.getPrimaryIP().getHostAddress() : null;
         case NodesTab.COLUMN_PLATFORM:
            return node.getPlatformName();
         case NodesTab.COLUMN_AGENT_VERSION:
            return node.getAgentVersion();
         case NodesTab.COLUMN_RACK:
            if (node.getPhysicalContainerId() != 0)
            {
               Rack rack = session.findObjectById(node.getPhysicalContainerId(), Rack.class);
               if (rack != null)
               {
                  return String.format(Messages.get().GeneralInfo_Units, rack.getObjectName(),
                          rack.isTopBottomNumbering() ? node.getRackPosition() : node.getRackPosition() - node.getRackHeight() + 1,
                          rack.isTopBottomNumbering() ? node.getRackPosition() + node.getRackHeight() - 1 : node.getRackPosition());
               }
            }
            return ""; //$NON-NLS-1$
		}
		return null;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.viewers.ITableColorProvider#getForeground(java.lang.Object, int)
	 */
	@Override
	public Color getForeground(Object element, int columnIndex)
	{
		AbstractNode node = (AbstractNode)element;
		switch(columnIndex)
		{
			case NodesTab.COLUMN_STATUS:
				return StatusDisplayInfo.getStatusColor(node.getStatus());
			default:
				return null;
		}
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.viewers.ITableColorProvider#getBackground(java.lang.Object, int)
	 */
	@Override
	public Color getBackground(Object element, int columnIndex)
	{
		return null;
	}
}
